| Title: | Transformation Boosting Machines |
|---|---|
| Description: | Boosting the likelihood of conditional and shift transformation models as introduced in <DOI:10.1007/s11222-019-09870-4>. |
| Authors: | Torsten Hothorn [aut, cre] (ORCID: <https://orcid.org/0000-0001-8301-0471>) |
| Maintainer: | Torsten Hothorn <[email protected]> |
| License: | GPL-2 |
| Version: | 0.3-10 |
| Built: | 2026-05-22 16:31:12 UTC |
| Source: | https://github.com/r-forge/ctm |
Employs maximisation of the likelihood for estimation of conditional transformation models
ctmboost(model, formula, data = list(), weights = NULL, method = quote(mboost::mboost), ...)ctmboost(model, formula, data = list(), weights = NULL, method = quote(mboost::mboost), ...)
model |
an object of class |
formula |
a model formula describing how the parameters of
|
data |
an optional data frame of observations. |
weights |
an optional vector of weights. |
method |
a call to |
... |
additional arguments to |
The parameters of model depend on explanatory variables in a
possibly structured additive way (see Hothorn, 2020). The number of boosting
iterations is a hyperparameter which needs careful tuning.
An object of class ctmboost with predict and
logLik methods.
Torsten Hothorn (2020). Transformation Boosting Machines. Statistics and Computing, 30, 141–152.
if (require("TH.data") && require("tram")) { data("bodyfat", package = "TH.data") ### estimate unconditional model m_mlt <- BoxCox(DEXfat ~ 1, data = bodyfat, prob = c(.1, .99)) ### get corresponding in-sample log-likelihood logLik(m_mlt) ### estimate conditional transformation model bm <- ctmboost(m_mlt, formula = DEXfat ~ ., data = bodyfat, method = quote(mboost::mboost)) ### in-sample log-likelihood (NEEDS TUNING OF mstop!) logLik(bm) ### evaluate conditional densities for two observations predict(bm, newdata = bodyfat[1:2,], type = "density") }if (require("TH.data") && require("tram")) { data("bodyfat", package = "TH.data") ### estimate unconditional model m_mlt <- BoxCox(DEXfat ~ 1, data = bodyfat, prob = c(.1, .99)) ### get corresponding in-sample log-likelihood logLik(m_mlt) ### estimate conditional transformation model bm <- ctmboost(m_mlt, formula = DEXfat ~ ., data = bodyfat, method = quote(mboost::mboost)) ### in-sample log-likelihood (NEEDS TUNING OF mstop!) logLik(bm) ### evaluate conditional densities for two observations predict(bm, newdata = bodyfat[1:2,], type = "density") }
Employs maximisation of the likelihood for estimation of shift transformation models
stmboost(model, formula, data = list(), weights = NULL, method = quote(mboost::mboost), mltargs = list(), ...)stmboost(model, formula, data = list(), weights = NULL, method = quote(mboost::mboost), mltargs = list(), ...)
model |
an object of class |
formula |
a model formula describing how the parameters of
|
data |
an optional data frame of observations. |
weights |
an optional vector of weights. |
method |
a call to |
mltargs |
a list with arguments to be passed to
|
... |
additional arguments to |
The parameters of model depend on explanatory variables in a
possibly structured additive way (see Hothorn, 2020). The number of boosting
iterations is a hyperparameter which needs careful tuning.
An object of class stmboost with predict and
logLik methods.
Torsten Hothorn (2020). Transformation Boosting Machines. Statistics and Computing, 30, 141–152.
if (require("TH.data") && require("tram")) { data("bodyfat", package = "TH.data") ### estimate unconditional model m_mlt <- BoxCox(DEXfat ~ 1, data = bodyfat, prob = c(.1, .99)) ### get corresponding in-sample log-likelihood logLik(m_mlt) ### estimate conditional transformation model bm <- stmboost(m_mlt, formula = DEXfat ~ ., data = bodyfat, method = quote(mboost::mboost)) ### in-sample log-likelihood (NEEDS TUNING OF mstop!) logLik(bm) ### evaluate conditional densities for two observations predict(bm, newdata = bodyfat[1:2,], type = "density") }if (require("TH.data") && require("tram")) { data("bodyfat", package = "TH.data") ### estimate unconditional model m_mlt <- BoxCox(DEXfat ~ 1, data = bodyfat, prob = c(.1, .99)) ### get corresponding in-sample log-likelihood logLik(m_mlt) ### estimate conditional transformation model bm <- stmboost(m_mlt, formula = DEXfat ~ ., data = bodyfat, method = quote(mboost::mboost)) ### in-sample log-likelihood (NEEDS TUNING OF mstop!) logLik(bm) ### evaluate conditional densities for two observations predict(bm, newdata = bodyfat[1:2,], type = "density") }